pub struct ReportArgs {
pub shared: SharedFlags,
pub input: Option<PathBuf>,
pub format: String,
pub output: Option<PathBuf>,
pub exploit_paths: bool,
pub summary: bool,
pub history: bool,
pub regression: bool,
}Fields
input: Option<PathBuf>Path to audit result JSON
format: StringOutput report format
output: Option<PathBuf>Output file path
exploit_paths: boolInclude exploit paths
summary: boolSummary only
history: boolShow historical audit score trends from the local SQLite history db
regression: boolHighlight findings that are new since the last recorded audit