pub fn parse_source(content: &str) -> SourceFileExpand description
Parse a full Solidity source string into a structured representation.
pub fn parse_source(content: &str) -> SourceFileParse a full Solidity source string into a structured representation.